package org.apache.torque.om.mapper;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.sql.ResultSet;
import java.sql.SQLException;

import org.apache.torque.TorqueException;

/**
 * Maps a database record to a Integer.
 *
 * @version $Id: IntegerMapper.java 1380467 2012-09-04 07:33:05Z tfischer $
 */
public class IntegerMapper implements RecordMapper<Integer>
{
    /** Serial Version UID. */
    private static final long serialVersionUID = 1L;

    /** The internal offset for the mapper. */
    private final int internalOffset;

    /**
     * Constructs a IntegerMapper with an offset of 0.
     */
    public IntegerMapper()
    {
        internalOffset = 0;
    }

    /**
     * Constructs a IntegerMapper with the given offset.
     *
     * @param offset the additional offset (0 based).
     */
    public IntegerMapper(int offset)
    {
        this.internalOffset = offset;
    }

    public Integer processRow(
                ResultSet resultSet,
                int rowOffset)
            throws TorqueException
    {
        try
        {
            Integer result = Integer.valueOf(
                    resultSet.getInt(rowOffset + internalOffset + 1));
            if (result == 0 && resultSet.wasNull())
            {
                return null;
            }
            return result;
        }
        catch (SQLException e)
        {
            throw new TorqueException("Result could not be mapped to a Integer",
                    e);
        }
    }
}
